"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupAutoDeletion = void 0;
const Logger_1 = require("@joplin/utils/Logger");
const Folder_1 = require("../../models/Folder");
const Setting_1 = require("../../models/Setting");
const Note_1 = require("../../models/Note");
const time_1 = require("@joplin/utils/time");
const shim_1 = require("../../shim");
const logger = Logger_1.default.create('permanentlyDeleteOldData');
const permanentlyDeleteOldItems = async (ttl = null) => {
    ttl = ttl === null ? Setting_1.default.value('trash.ttlDays') * time_1.Day : ttl;
    logger.info(`Processing items older than ${ttl}ms...`);
    if (!Setting_1.default.value('trash.autoDeletionEnabled')) {
        logger.info('Auto-deletion is not enabled - skipping');
        return;
    }
    const result = await Folder_1.default.trashItemsOlderThan(ttl);
    logger.info('Items to permanently delete:', result);
    await Note_1.default.batchDelete(result.noteIds, { sourceDescription: 'permanentlyDeleteOldItems' });
    // We only auto-delete folders if they are empty.
    for (const folderId of result.folderIds) {
        const noteIds = await Folder_1.default.noteIds(folderId, { includeDeleted: true });
        if (!noteIds.length) {
            logger.info(`Deleting empty folder: ${folderId}`);
            await Folder_1.default.delete(folderId);
        }
        else {
            logger.info(`Skipping non-empty folder: ${folderId}`);
        }
    }
};
const setupAutoDeletion = async () => {
    await permanentlyDeleteOldItems();
    shim_1.default.setInterval(async () => {
        await permanentlyDeleteOldItems();
    }, 18 * time_1.Hour);
};
exports.setupAutoDeletion = setupAutoDeletion;
exports.default = permanentlyDeleteOldItems;
//# sourceMappingURL=permanentlyDeleteOldItems.js.map